
import React, { useEffect } from 'react';
import { Helmet } from 'react-helmet';
import { LaunchpadHero } from '@/components/launchpad/LaunchpadHero';
import { LaunchpadPartners } from '@/components/launchpad/LaunchpadPartners';
import { LaunchpadProblem } from '@/components/launchpad/LaunchpadProblem';
import { LaunchpadSolution } from '@/components/launchpad/LaunchpadSolution';
import { LaunchpadBenefits } from '@/components/launchpad/LaunchpadBenefits';
import { LaunchpadTimeline } from '@/components/launchpad/LaunchpadTimeline';
import { LaunchpadInvestor } from '@/components/launchpad/LaunchpadInvestor';
import { LaunchpadStory } from '@/components/launchpad/LaunchpadStory';
import { LaunchpadFAQ } from '@/components/launchpad/LaunchpadFAQ';
import { LaunchpadCTA } from '@/components/launchpad/LaunchpadCTA';
import { Toaster } from '@/components/ui/toaster';
import { Squares } from '@/components/ui/squares-background';
import { Particles } from '@/components/ui/particles';

const LaunchpadPage = () => {
  // SEO metadata
  const pageTitle = "NoCodeLab Vibe Coding Launchpad - Turn Your Idea into a Live Application";
  const shortTitle = "Vibe Coding Launchpad";
  const pageDescription = "Join NoCodeLab's Vibe Coding Launchpad program to transform your idea into a successful application. Get expert guidance, technical support, and investment opportunities. Start your no-code journey with our innovative Vibe Coding methodology.";
  const canonicalUrl = "https://nocodelab.com/launchpad";
  const keywords = "vibe coding, no-code development, app builder, startup incubator, tech launchpad, application development, startup program, tech mentorship, no code platform, visual development, rapid prototyping, startup accelerator, tech innovation, app development program, founder program";
  
  // Image metadata for social sharing
  const ogImage = "https://nocodelab.com/images/vibe-coding-launchpad-og.jpg";
  const twitterImage = "https://nocodelab.com/images/vibe-coding-launchpad-twitter.jpg";

  // Structured data for SEO
  const structuredData = {
    "@context": "https://schema.org",
    "@type": "Product",
    "name": "NoCodeLab Vibe Coding Launchpad Program",
    "description": pageDescription,
    "brand": {
      "@type": "Brand",
      "name": "NoCodeLab"
    },
    "provider": {
      "@type": "Organization",
      "name": "NoCodeLab",
      "url": "https://nocodelab.com",
      "logo": "https://nocodelab.com/images/logo.png",
      "sameAs": [
        "https://twitter.com/nocodelab",
        "https://linkedin.com/company/nocodelab",
        "https://instagram.com/nocodelab"
      ]
    },
    "offers": {
      "@type": "Offer",
      "price": "250",
      "priceCurrency": "USD",
      "availability": "https://schema.org/InStock",
      "priceValidUntil": "2024-12-31",
      "url": canonicalUrl
    },
    "aggregateRating": {
      "@type": "AggregateRating",
      "ratingValue": "4.8",
      "reviewCount": "150",
      "bestRating": "5",
      "worstRating": "1"
    },
    "category": "Technology Education Program",
    "audience": {
      "@type": "Audience",
      "audienceType": "Entrepreneurs and Startup Founders"
    },
    "educationalLevel": "Beginner to Advanced",
    "hasCourse": {
      "@type": "Course",
      "name": "Vibe Coding Methodology",
      "description": "Learn to build applications using the innovative Vibe Coding methodology",
      "provider": {
        "@type": "Organization",
        "name": "NoCodeLab",
        "sameAs": "https://nocodelab.com"
      }
    }
  };

  return (
    <>
      <Helmet htmlAttributes={{ lang: 'en' }}>
        <title>{pageTitle}</title>
        <meta name="description" content={pageDescription} />
        <meta name="keywords" content={keywords} />
        <meta name="author" content="NoCodeLab" />
        <meta name="robots" content="index, follow, max-image-preview:large, max-snippet:-1, max-video-preview:-1" />
        <meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <meta name="application-name" content={shortTitle} />
        <meta name="apple-mobile-web-app-title" content={shortTitle} />
        <meta name="theme-color" content="#7c3aed" />
        
        {/* Open Graph tags */}
        <meta property="og:title" content={pageTitle} />
        <meta property="og:description" content={pageDescription} />
        <meta property="og:type" content="website" />
        <meta property="og:url" content={canonicalUrl} />
        <meta property="og:site_name" content="NoCodeLab" />
        <meta property="og:locale" content="en_US" />
        <meta property="og:image" content={ogImage} />
        <meta property="og:image:width" content="1200" />
        <meta property="og:image:height" content="630" />
        <meta property="og:image:type" content="image/jpeg" />
        <meta property="og:updated_time" content={new Date().toISOString()} />
        
        {/* Twitter Card tags */}
        <meta name="twitter:card" content="summary_large_image" />
        <meta name="twitter:site" content="@nocodelab" />
        <meta name="twitter:creator" content="@nocodelab" />
        <meta name="twitter:title" content={pageTitle} />
        <meta name="twitter:description" content={pageDescription} />
        <meta name="twitter:image" content={twitterImage} />
        <meta name="twitter:image:alt" content="NoCodeLab Vibe Coding Launchpad Program Preview" />
        
        {/* Additional SEO tags */}
        <meta name="format-detection" content="telephone=no" />
        <meta name="google" content="nositelinkssearchbox" />
        <meta name="google" content="notranslate" />
        <meta name="rating" content="General" />
        <meta name="referrer" content="strict-origin-when-cross-origin" />
        
        {/* Canonical URL */}
        <link rel="canonical" href={canonicalUrl} />
        
        {/* Alternate languages if available */}
        <link rel="alternate" href="https://nocodelab.com/es/launchpad" hrefLang="es" />
        <link rel="alternate" href="https://nocodelab.com/fr/launchpad" hrefLang="fr" />
        <link rel="alternate" href={canonicalUrl} hrefLang="x-default" />
        
        {/* JSON-LD structured data */}
        <script type="application/ld+json">
          {JSON.stringify(structuredData)}
        </script>
      </Helmet>

      <main className="min-h-screen flex flex-col bg-[#070707]" role="main">
        {/* Background setup with animated elements */}
        <div className="fixed inset-0 -z-10" aria-hidden="true">
          <div className="absolute inset-0 bg-gradient-to-b from-[#070707] to-[#0a0a0a]" />
          <div className="absolute inset-0 opacity-30">
            <Squares 
              speed={0.2} 
              direction="diagonal" 
              squareSize={60} 
              borderColor="#545454" 
              opacity={0.2}
            />
          </div>
          <div className="absolute inset-0 pointer-events-none">
            <Particles
              className="absolute inset-0"
              quantity={100}
              staticity={50}
              color="#7c3aed"
              vx={0.1}
              size={0.3}
            />
          </div>
        </div>
        
        {/* Main content with no spacing between sections */}
        <article>
          <LaunchpadHero />
          <LaunchpadSolution />
          <LaunchpadTimeline />
          <LaunchpadStory />
          <LaunchpadProblem />
          <LaunchpadBenefits />
          <LaunchpadFAQ />
          <LaunchpadCTA />
        </article>
        
        <Toaster />
      </main>
    </>
  );
};

export default LaunchpadPage;
